# 1. Record Architecture Decisions

Date: 2025-12-04

## Status

Accepted

## Context

We need a way to record architectural decisions, context, and consequences.

## Decision

We will use Architecture Decision Records (ADRs) as described by Michael Nygard.

## Consequences

See `docs/adr/` for future decisions.
